@@ -5,8 +5,12 @@ from symbl.async_api.Audio import Audio
 from symbl.async_api.Video import Video
 from symbl.async_api.Text import Text
 
+from symbl.Connection import Connection
+from symbl.streaming_api.StreamingConnection import StreamingConnection
+
 from symbl.conversations_api.ConversationsApi import ConversationsApi
 from symbl.telephony_api.TelephonyApi import TelephonyApi
+from symbl.streaming_api.StreamingApi import StreamingApi
 from symbl.jobs_api.Job import Job
 from symbl.jobs_api.JobStatus import JobStatus
 
@@ -14,4 +18,5 @@ Audio = Audio()
 Video = Video()
 Text = Text()
 Conversations = ConversationsApi()
-Telephony = TelephonyApi()
\ No newline at end of file
+Telephony = TelephonyApi()
+Streaming = StreamingApi()
